@@ -53,7 +53,7 @@ class Command(BaseCommand):
                 source_meta = json.load(file)
             source = SourceTable(
                 pk=int(pk),
-                source_database=int(source_meta["database"]),
+                source_database_id=int(source_meta["database"]),
                 source_table=source_meta["table"],
                 description=source_meta["description"]
             )
@@ -87,7 +87,7 @@ class Command(BaseCommand):
                 pk=int(pk),
                 description=reflection_meta["description"],
                 source_table=reflection_meta["source_table"],
-                destination_database=int(
+                destination_database_id=int(
                     reflection_meta["destination_database"]),
                 destination_table=reflection_meta["destination_table"],
                 last_commit=reflection_meta["last_commit"],
